#!/bin/bash
#

# need an in source build

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=libwda
origpkgver=v2_30_0
pkgver=${origpkgver}a
pkgtag=wda_${origpkgver}
ssibuildshims_version=v1_04_15
pkgtarfile=ifdhc-${package}.${pkgtag}.tbz2

get_this_dir

get_ssibuildshims

source define_basics NO_QUAL

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
   exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${pkgdir}/libwda
if [ ! -d ${pkgdir}/libwda ]
then
   echo "ERROR: failed to create ${pkgdir}/libwda"
   exit 1
fi

cd ${pkgdir}/libwda  || ssi_die "ERROR: could not cd ${pkgdir}/libwda"
tar xf ${tardir}/${pkgtarfile} || ssi_die "ERROR: failed to unwind ${pkgtarfile}"
for patch in "${patchdir}/libwda.patch"; do
  patch -b -p0 < "${patch}" || ssi_die "application of patch ${patch} failed."
done

set -x

cd ${pkgdir}/libwda/src

make LIBWDA_VERSION=${origpkgver} all || ssi_die "ERROR: make all failed"
make PREFIX=${pkgdir} install || ssi_die "ERROR: make install failed"
make clean || ssi_die "ERROR: make clean failed"

cd ${pkgdir} 
cp -pr libwda/ups ../ups

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi


# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_QUAL

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir} || ssi_die "ERROR: setup failed"

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
fi

exit 0
